==> foundation-ui-components-1.1.1.tgz: package/src/common/carousal/NsCarousal.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { useRef, useCallback } from 'react';
import Slider from 'react-slick';
import 'slick-carousel/slick/slick.css';
import 'slick-carousel/slick/slick-theme.css';
import defaultCarousalSettings from './slickSetting';
import CarousalControl from './CarousalControl';
import { NsCarousalProps } from './types';

const SlickContainer = styled(Box)(() => {
    return {
        padding: '20px 0 50px',
        '.slick-slide': {
            display: 'flex',
            justifyContent: 'center',
        },
    };
});

export default function NsCarousal({ entries, renderEntry, allEntryLink, settings }: NsCarousalProps) {
    const sliderRef = useRef();
    const prev = useCallback(() => {
        if (sliderRef.current) {
            const slider = sliderRef.current as any;
            slider.slickPrev();
        }
    }, [sliderRef]);
    const next = useCallback(() => {
        if (sliderRef.current) {
            const slider = sliderRef.current as any;
            slider.slickNext();
        }
    }, [sliderRef]);
    return (
        <SlickContainer className="brand-carousal">
            <CarousalControl prev={prev} next={next} viewAllUrl={allEntryLink} />
            <Slider {...{ ...defaultCarousalSettings, ...settings }} ref={sliderRef as any}>
                {entries.map((entry, index) => {
                    return renderEntry(entry, index);
                })}
            </Slider>
        </SlickContainer>
    );
}

==> foundation-ui-components-1.9.1.tgz: package/src/common/carousal/NsCarousal.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { ReactNode, useCallback, useRef } from 'react';
import Slider from 'react-slick';

import CarousalControl from './CarousalControl';
import defaultCarousalSettings from './slickSetting';

import 'slick-carousel/slick/slick-theme.css';
import 'slick-carousel/slick/slick.css';

const SlickContainer = styled(Box)(() => {
    return {
        padding: '20px 0 50px',
        '.slick-slide': {
            display: 'flex',
            justifyContent: 'center',
        },
    };
});
interface CarousalProps<T = any> {
    entries: T[];
    renderEntry(entry: T, index: number): ReactNode;
    allEntryLink: string;
    settings: any;
}

export default function NsCarousal({ entries, renderEntry, allEntryLink, settings }: CarousalProps) {
    const sliderRef = useRef();
    const prev = useCallback(() => {
        if (sliderRef.current) {
            const slider = sliderRef.current as any;
            slider.slickPrev();
        }
    }, [sliderRef]);
    const next = useCallback(() => {
        if (sliderRef.current) {
            const slider = sliderRef.current as any;
            slider.slickNext();
        }
    }, [sliderRef]);
    return (
        <SlickContainer className="brand-carousal">
            <CarousalControl prev={prev} next={next} viewAllUrl={allEntryLink} />
            <Slider {...{ ...defaultCarousalSettings, ...settings }} ref={sliderRef as any}>
                {entries.map((entry, index) => {
                    return renderEntry(entry, index);
                })}
            </Slider>
        </SlickContainer>
    );
}
